<?php
/**
 * Contains methods for customizing the theme customization screen.
 *
 * @link http://codex.wordpress.org/Theme_Customization_API
 * @since Hayya 1.0
 */

 if ( ! defined( 'ABSPATH' ) ) { exit; }

class HayyaThemeCustomize {

	/**
	 *
	 */
	public static $fonts_list = array( 'body', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' );

	/**
	 * This hooks into 'customize_register' (available as of WP 3.4) and allows
	 * you to add new sections and controls to the Theme Customize screen.
	 *
	 * Note: To enable instant preview, we have to actually write a bit of custom
	 * javascript. See live_preview() for more.
	 *
	 * @see add_action('customize_register',$func)
	 * @param \WP_Customize_Manager $wp_customize
	 * @link http://ottopress.com/2012/how-to-leverage-the-theme-customizer-in-your-own-themes/
	 * @since Hayya 1.0
	 */
	public static function register( $wp_customize ) {

		$transport = ( $wp_customize->selective_refresh ? 'postMessage' : 'refresh' );

		$defaults = HayyaTheme::defaults();

		// Layout Section
		$wp_customize->add_section( 'ht-layout',
			array(
				'title'	   => __( 'Layout', 'hayya' ),
				'priority'	=> 1,
				'capability'  => 'edit_theme_options',
				'description' => __( 'Customize Hayya Layout.', 'hayya' ), //Descriptive tooltip
			)
		);

		// layout mode
		$wp_customize->add_setting(
			'layout-mode' ,
			array(
				'default' => $defaults['layout-mode'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'sanitize_key',
			)
		);
		$wp_customize->add_control(
			'layout-mode',
			array(
				'type'	   => 'radio',
				'label'	  => __( 'Layout Mode', 'hayya' ),
				'settings'   => 'layout-mode',
				'section'	=> 'ht-layout',
				'choices'  => array(
					'layout-wide'  => __( 'Wide', 'hayya' ),
					'layout-boxed' => __( 'Boxed', 'hayya' ),
				),
				'priority'   => 1,
			)
		);

		// Layout width
		$wp_customize->add_setting(
			'layout-width',
			array(
				'default' => $defaults['layout-width'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control(
			'layout-width',
			array(
				'type' 			=> 'text',
				'label'			=> __( 'Layout Width', 'hayya' ),
				'description' 	=> __( 'in boxed mode only.', 'hayya' ),
				'section'		=> 'ht-layout',
				'settings'   	=> 'layout-width',
				'priority'	   => 2,
			)
		);

		// container width
		$wp_customize->add_setting(
			'container-width',
			array(
				'default' => $defaults['container-width'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control(
			'container-width',
			array(
				'type' 			=> 'text',
				'label'			=> __( 'Container Width', 'hayya' ),
				'section'		=> 'ht-layout',
				'settings'   	=> 'container-width',
				'priority'	   => 3,
			)
		);

		// layout background color
		$wp_customize->add_setting(
			'layout-background-color' ,
			array(
				'default' => $defaults['layout-background-color'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'layout-background-color',
			array(
				'label'	  => __( 'Background Color', 'hayya' ),
				'settings'   => 'layout-background-color',
				'section'	=> 'ht-layout',
				'priority'   => 4,
			)
		) );

		// layout background image
		$wp_customize->add_setting(
			'layout-background-image' ,
			array(
				'default' => $defaults['layout-background-image'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( new WP_Customize_Image_Control(
			$wp_customize,
			'layout-background-image',
			array(
				'label'	  => __( 'Background Image', 'hayya' ),
				'settings'   => 'layout-background-image',
				'section'	=> 'ht-layout',
				'priority'   => 5,
			)
		) );

		// Color Schemes
		$wp_customize->add_section( 'ht-colors',
			array(
				'title'	   => __( 'Color Schemes', 'hayya' ), //Visible title of section
				'priority'	=> 2, //Determines what order this appears in
				'capability'  => 'edit_theme_options', //Capability needed to tweak
				'description' => __( 'customize Hayya colors.', 'hayya' ), //Descriptive tooltip
			)
		);
		$colors = array(
			'first-color'   => $defaults['first-color'],
			'second-color'  => $defaults['second-color'],
			'third-color'   => $defaults['third-color'],
			'fourth-color'  => $defaults['fourth-color'],
			'fifth-color'   => $defaults['fifth-color'],
		);
		foreach ( $colors as $key => $value ) {
			switch ( $key ) {
				case 'second-color':
					$label = __( 'Second Color', 'hayya' );
					break;
				case 'third-color':
					$label = __( 'Third Color', 'hayya' );
					break;
				case 'fourth-color':
					$label = __( 'Fourth Color', 'hayya' );
					break;
				case 'fifth-color':
					$label = __( 'Fifth Color', 'hayya' );
					break;
				default:
					$label = __( 'First Color', 'hayya' );
					break;
			}
			$wp_customize->add_setting(
				$key ,
				array(
					'default' => $value,
					'transport' => 'postMessage',
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control( new WP_Customize_Color_Control(
				$wp_customize,
				$key,
				array(
					'label'	  => $label,
					'settings'   => $key,
					'priority'   => 1,
					'section'	=> 'ht-colors',
				)
			) );
		} // End foreach().

		if ( class_exists( 'HayyaFonts' ) ) {

			if ( isset( self::$fonts_list ) && ! empty( self::$fonts_list ) && is_array( self::$fonts_list ) ) {

				// Typography Settings
				$wp_customize->add_section( 'ht-typography',
					array(
						'title'	   => __( 'Typography Settings', 'hayya' ), //Visible title of section
						'priority'	=> 3, //Determines what order this appears in
						'capability'  => 'edit_theme_options', //Capability needed to tweak
						'description' => __( 'customize Hayya typography.', 'hayya' ), //Descriptive tooltip
					)
				);

				foreach ( self::$fonts_list as $k ) {
					$wp_customize->add_setting(
						$k.'-font',
						array(
							'default' => $defaults[$k . '-font'],
							'transport' => 'postMessage',
							'sanitize_callback' => 'sanitize_text_field',
						)
					);
					$wp_customize->add_setting(
						$k.'-size',
						array(
							'default' => $defaults[$k . '-size'],
							'transport' => 'postMessage',
							'sanitize_callback' => 'sanitize_text_field',
						)
					);
				}
			}

			$setting = array();
			foreach ( self::$fonts_list as $k ) {
				$setting[$k . '-font-link'] = $k . '-font';
				$setting[$k . '-size-link'] = $k . '-size';
			}

			$wp_customize->add_control( new HayyaFonts(
				$wp_customize,
				'font_family_control',
				array(
					'section'			=> 'ht-typography',
					'settings'			=> $setting,
				)
			) );
		}

		// Header Section
		$wp_customize->add_section( 'ht-header',
			array(
				'title'	   => __( 'Header', 'hayya' ),
				'priority'	=> 4,
				'capability'  => 'edit_theme_options',
				'description' => __( 'customize Hayya Header.', 'hayya' ), //Descriptive tooltip
		   )
		);

		// hayyaBuild Header
		$wp_customize->add_setting(
			'hayyabuild-header' ,
			array(
				'default'   => $defaults['hayyabuild-header'],
				'transport' => 'postMessage',
				'sanitize_callback' => array( 'HayyaThemeCustomize', 'sanitize_checkbox' ),
			)
		);
		$wp_customize->add_control(
			'hayyabuild-header',
			array(
				'type'	   => 'checkbox',
				'label'	  => __( 'HayyaBuild Header', 'hayya' ),
				'description' => __( 'You have to install HayyaBuild Lite plugin.', 'hayya' ),
				'settings'   => 'hayyabuild-header',
				'section'	=> 'ht-header',
				'priority'   => 1,
			)
		);

		// header height
		$wp_customize->add_setting(
			'header-height',
			array(
				'default' => $defaults['header-height'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control(
			'header-height',
			array(
				'type' 			=> 'text',
				'label'			=> __( 'Header Height', 'hayya' ),
				'section'		=> 'ht-header',
				'settings'   	=> 'header-height',
				'priority'	   => 2,
			)
		);

		// Header Logo
		$wp_customize->add_setting(
			'header-logo' ,
			array(
				'default' => $defaults['header-logo'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( new WP_Customize_Image_Control(
			$wp_customize,
			'header-logo',
			array(
				'label'	  => __( 'Header Logo', 'hayya' ),
				'settings'   => 'header-logo',
				'section'	=> 'ht-header',
				'priority'   => 3,
			)
		) );

		// Header Background
		$wp_customize->add_setting(
			'header-backgound' ,
			array(
				'default' => $defaults['header-backgound'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( new WP_Customize_Image_Control(
			$wp_customize,
			'header-backgound',
			array(
				'label'	  => __( 'Header Backgound Image', 'hayya' ),
				'settings'   => 'header-backgound',
				'section'	=> 'ht-header',
				'priority'   => 4,
			)
		) );

		// Header Text
		$wp_customize->add_setting(
			'header-text' ,
			array(
				'default' => $defaults['header-text'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'wp_kses_post',
			)
		);
		$wp_customize->add_control(
			'header-text',
			array(
				'type'	   => 'textarea',
				'label'	  => __( 'Header Text', 'hayya' ),
				'settings'   => 'header-text',
				'section'	=> 'ht-header',
				'priority'   => 5,
			)
		);

		// Footer Section
		$wp_customize->add_section( 'ht-footer',
			array(
				'title'	   => __( 'Footer', 'hayya' ),
				'priority'	=> 5,
				'capability'  => 'edit_theme_options',
				'description' => __( 'customize Hayya Footer.', 'hayya' ), //Descriptive tooltip
		   )
		);

		// hayyaBuild Footer
		$wp_customize->add_setting(
			'hayyabuild-footer' ,
			array(
				'default'   => $defaults['hayyabuild-footer'],
				'transport' => 'postMessage',
				'sanitize_callback' => array( 'HayyaThemeCustomize', 'sanitize_checkbox' ),
			)
		);
		$wp_customize->add_control(
			'hayyabuild-footer',
			array(
				'type'	   => 'checkbox',
				'label'	  => __( 'HayyaBuild Footer', 'hayya' ),
				'description' => __('You have to install HayyaBuild Lite plugin.', 'hayya' ),
				'settings'   => 'hayyabuild-footer',
				'section'	=> 'ht-footer',
				'priority'   => 1,
			)
		);

		// Footer Widgets
		$wp_customize->add_setting(
			'show-footer-widgets' ,
			array(
				'default'   => $defaults['show-footer-widgets'],
				'transport' => 'postMessage',
				'sanitize_callback' => array( 'HayyaThemeCustomize', 'sanitize_checkbox' ),
			)
		);
		$wp_customize->add_control(
			'show-footer-widgets',
			array(
				'type'	   => 'checkbox',
				'label'	  => __( 'Display Footer Widgets', 'hayya' ),
				'settings'   => 'show-footer-widgets',
				'section'	=> 'ht-footer',
				'priority'   => 2,
			)
		);

		// Footer Background
		$wp_customize->add_setting(
			'footer-backgound' ,
			array(
				'default' => $defaults['footer-backgound'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( new WP_Customize_Image_Control(
			$wp_customize,
			'footer-backgound',
			array(
				'label'	  => __( 'Footer Backgound Image', 'hayya' ),
				'settings'   => 'footer-backgound',
				'section'	=> 'ht-footer',
				'priority'   => 2,
			)
		) );

		// Footer Text
		$wp_customize->add_setting(
			'footer-text' ,
			array(
				'default' => $defaults['footer-text'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'wp_kses_post',
			)
		);
		$wp_customize->add_control(
			'footer-text',
			array(
				'type'	   => 'textarea',
				'label'	  => __( 'Footer Text', 'hayya' ),
				'settings'   => 'footer-text',
				'section'	=> 'ht-footer',
				'priority'   => 3,
			)
		);

		// Footer copyrights
		$wp_customize->add_setting(
			'show-copyright' ,
			array(
				'default'   => $defaults['show-copyright'],
				'transport' => 'postMessage',
				'sanitize_callback' => array( 'HayyaThemeCustomize', 'sanitize_checkbox' ),
			)
		);
		$wp_customize->add_control(
			'show-copyright',
			array(
				'type'	   => 'checkbox',
				'label'	  => __( 'Display Copyright', 'hayya' ),
				'section'	=> 'ht-footer',
				'priority'   => 4,
			)
		);

		// copyright Text
		$wp_customize->add_setting(
			'footer-copyright-text' ,
			array(
				'default' => $defaults['footer-copyright-text'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'wp_kses_post',
			)
		);
		$wp_customize->add_control(
			'footer-copyright-text',
			array(
				'type'	   => 'textarea',
				'label'	  => __( 'Copyright Text', 'hayya' ),
				'settings'   => 'footer-copyright-text',
				'section'	=> 'ht-footer',
				'priority'   => 5,
			)
		);

		$wp_customize->add_setting(
			'copyright-alignment' ,
			array(
				'default' => $defaults['copyright-alignment'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'sanitize_key',
			)
		);
		$wp_customize->add_control(
			'copyright-alignment',
			array(
				'type'	   => 'select',
				'label'	  => __( 'Copyright Alignment', 'hayya' ),
				'settings'   => 'copyright-alignment',
				'section'	=> 'ht-footer',
				'choices'	=> array(
						'left' => 'Left',
						'center' => 'Center',
						'right' => 'Right',
					),
				'priority'   => 6,
			)
		);

		// Blog Section
		$wp_customize->add_section( 'ht-blog',
		   array(
			  'title'	   => __( 'Blog', 'hayya' ),
			  'priority'	=> 6,
			  'capability'  => 'edit_theme_options',
			  'description' => __( 'customize Hayya Blog.', 'hayya' ), //Descriptive tooltip
		   )
		);

		$wp_customize->add_setting(
			'image-zoom-effect' ,
			array(
				'default'   => $defaults['image-zoom-effect'],
				'transport' => 'postMessage',
				'sanitize_callback' => array( 'HayyaThemeCustomize', 'sanitize_checkbox' ),
			)
		);
		$wp_customize->add_control(
			'image-zoom-effect',
			array(
				'type'	   => 'checkbox',
				'label'	  => __( 'Featured image zoom effect', 'hayya' ),
				'section'	=> 'ht-blog',
				'priority'   => 1,
			)
		);

		$wp_customize->add_setting(
			'show-single-sidebar' ,
			array(
				'default'   => $defaults['show-single-sidebar'],
				'transport' => 'postMessage',
				'sanitize_callback' => array( 'HayyaThemeCustomize', 'sanitize_checkbox'),
			)
		);
		$wp_customize->add_control(
			'show-single-sidebar',
			array(
				'type'	   => 'checkbox',
				'label'	  => __( 'Display Right Sidebar', 'hayya' ),
				'settings'   => 'show-single-sidebar',
				'section'	=> 'ht-blog',
				'priority'   => 2,
			)
		);

		$wp_customize->add_setting(
			'show-related-and-author' ,
			array(
				'default'   => $defaults['show-related-and-author'],
				'transport' => 'postMessage',
				'sanitize_callback' => array( 'HayyaThemeCustomize', 'sanitize_checkbox'),
			)
		);
		$wp_customize->add_control(
			'show-related-and-author',
			array(
				'type'	   => 'checkbox',
				'label'	  => __( 'Display Related Posts', 'hayya' ),
				'settings'   => 'show-related-and-author',
				'section'	=> 'ht-blog',
				'priority'   => 3,
			)
		);

		$wp_customize->add_setting(
			'show-author-card' ,
			array(
				'default'   => $defaults['show-related-and-author'],
				'transport' => 'postMessage',
				'sanitize_callback' => array( 'HayyaThemeCustomize', 'sanitize_checkbox' ),
			)
		);
		$wp_customize->add_control(
			'show-author-card',
			array(
				'type'	   => 'checkbox',
				'label'	  => __( 'Display Author card', 'hayya' ),
				'settings'   => 'show-author-card',
				'section'	=> 'ht-blog',
				'priority'   => 4,
			)
		);

		$wp_customize->add_setting(
			'default-posts-image' ,
			array(
				'default' => $defaults['default-posts-image'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( new WP_Customize_Image_Control(
			$wp_customize,
			'default-posts-image',
			array(
				'label'	  => __( 'Default Posts Image', 'hayya' ),
				'settings'   => 'default-posts-image',
				'section'	=> 'ht-blog',
				'priority'   => 5,
			)
		) );

		$wp_customize->add_setting(
			'default-slider-image' ,
			array(
				'default' => $defaults['default-slider-image'],
				'transport' => 'postMessage',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control( new WP_Customize_Image_Control(
			$wp_customize,
			'default-slider-image',
			array(
				'label'	  => __( 'Default Slider Image', 'hayya' ),
				'settings'   => 'default-slider-image',
				'section'	=> 'ht-blog',
				'priority'   => 6,
			)
		) );

	   /*
	   * /- end hayya settings -/
	   */
   }

	/**
	* This will output the custom WordPress settings to the live theme's WP head.
	*
	* Used by hook: 'wp_head'
	*
	* @see add_action('wp_head',$func)
	* @since Hayya 1.0
	*/
	public static function header_output() {
		?>
		<!--Hayya Theme CSS-->
		<style type="text/css" id="hayya-style">
			<?php self::css(); ?>
		</style>
		<!--/Hayya Theme CSS-->
		<?php
	}

	/**
	 * generate CSS code
	 * @since Hayya 1.0
	 */
	public static function css() {
		$hayya_options = HayyaTheme::hayya_options( 'hayya_options' );

		$fonts = self::google_font();
		if ( ! empty( $fonts ) && is_array( $fonts ) ) {
			foreach ( $fonts as $key ) {
				$font = urlencode( $key );
				$font = esc_url( '//fonts.googleapis.com/css?family='.$font );
				echo esc_attr( '@import url(' . $font . ');' );
			}
		}

		foreach ( self::$fonts_list as $font ) {
			self::generate_css( $font, 'font-family', $font . '-font' );
			if ( $value = HayyaTheme::hayya_options( $font . '-size' ) ) {
				$height = ( float ) HayyaTheme::hayya_options( $font . '-size' ) * 1.4;
				echo esc_attr( $font ) . ' { font-size: ' . esc_attr( $value ) . 'rem; line-height: ' . esc_attr( $height ) . 'rem; }';
			}
		}

		echo '#primary-menu a { font-size: ' . esc_attr( HayyaTheme::hayya_options( 'body-size' ) ) . 'rem;}';

		if ( $layout_background_image = HayyaTheme::hayya_options( 'layout-background-image' ) ) {
			echo 'body { background: url("' . esc_url( $layout_background_image ) . '");}';
		} else {
			self::generate_css( 'body', 'background', 'layout-background-color' );
		}

		if ( $header_background = HayyaTheme::hayya_options( 'header-backgound' ) ) {
			echo '.site-header.page-header { background: url("' . esc_url( $header_background ) . '");background-size: cover;}';
		}

		if ( $footer_background = HayyaTheme::hayya_options( 'footer-backgound' ) ) {
			echo '.site-footer.page-footer { background-image: url("' . esc_url( $footer_background ) . '");background-size: cover;}';
		}

		self::generate_css( '#site-header.site-header', 'height', 'header-height' );
		self::generate_css( '#page.layout-boxed', 'width', 'layout-width' );
		self::generate_css( '.container', 'width', 'container-width' );

		self::get_schome();
	}

	/**
	* @since Hayya 1.0
	*/
	public static function get_schome() {
		$file = dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'extensions' .  DIRECTORY_SEPARATOR . 'color_schemes' . DIRECTORY_SEPARATOR . 'code.php';
		$css = '';
		if ( file_exists( $file ) ) {
			require_once $file;
			if ( class_exists( 'HayyaTheme_color_schemes' ) ) {


				$first = HayyaTheme::hayya_options( 'first-color' );
				$second = HayyaTheme::hayya_options( 'second-color' );
				$third = HayyaTheme::hayya_options( 'third-color' );
				$fourth = HayyaTheme::hayya_options( 'fourth-color' );
				$fifth = HayyaTheme::hayya_options( 'fifth-color' );

				$colors = array(
					'first' => $first,
					'second' => $second,
					'third' => $third,
					'fourth' => $fourth,
					'fifth' => $fifth,
				);

				if ( !empty( $colors ) && is_array( $colors ) ) {
					foreach( $colors as $key => $value ) {
						$css .= HayyaTheme_color_schemes::process(
							$key,
							HayyaThemeHelper::color(
								$value
							)
						);
					}
				}
			}
		}
		echo $css;
	}

	/**
	 * This will generate a line of CSS for use in header output. If the setting
	 * ($mod_name) has no defined value, the CSS will not be output.
	 *
	 * @uses get_theme_mod()
	 * @param string $selector CSS selector
	 * @param string $style The name of the CSS *property* to modify
	 * @param string $mod_name The name of the 'theme_mod' option to fetch
	 * @param string $prefix Optional. Anything that needs to be output before the CSS property
	 * @param string $postfix Optional. Anything that needs to be output after the CSS property
	 * @param bool $echo Optional. Whether to print directly to the page (default: true).
	 * @return string Returns a single line of CSS with selectors and a property.
	 * @since Hayya 1.0
	 */
	public static function generate_css( $selector, $style, $mod_name, $prefix = '', $postfix = '', $echo = true ) {
    	$return = '';
    	$mod = HayyaTheme::hayya_options( $mod_name );
    	if ( ! empty( $mod ) ) {
            $return = $selector . ' {' . $style . ': ' . $prefix . $mod . $postfix . ' ;}';
    		if ( $echo ) {
    			echo $return;
    		}
    	}
    	return $return;
	}

	/**
	* This outputs the javascript needed to automate the live settings preview.
	* Also keep in mind that this function isn't necessary unless your settings
	* are using 'transport'=>'postMessage' instead of the default 'transport'
	* => 'refresh'
	*
	* Used by hook: 'customize_preview_init'
	*
	* @see add_action('customize_preview_init',$func)
	* @since Hayya 1.0
	*/
	public static function live_preview() {
		$theme = wp_get_theme('hayya');
		wp_enqueue_script(
			'hayya-themecustomizer',
			get_template_directory_uri() . '/assets/js/hayya-customizer.min.js',
			array( 'jquery','customize-preview' ),
			$theme->get( 'Version' ),
			true
		);
	}

	/**
	 * This will generate a line of CSS google font
	 * @since Hayya 1.0
	 */
	public static function google_font() {
		$list = self::$fonts_list;
		$fonts = array();

		foreach ( $list as $font ) {
			if ( HayyaTheme::hayya_options( $font.'-font' ) ) {
				 if( false === strpos( HayyaTheme::hayya_options( $font . '-font' ), ',' ) ) $fonts[] = HayyaTheme::hayya_options( $font . '-font' );
			}
		}
		return array_unique( $fonts );
	}

	/**
	 * register partials
	 * @since Hayya 1.0
	 */
	public static function register_partials( WP_Customize_Manager $wp_customize ) {

		// Abort if selective refresh is not available.
		if ( ! isset( $wp_customize->selective_refresh ) ) {
			return;
		}
		$wp_customize->selective_refresh->add_partial( 'header-logo', array(
			'selector' => '#main-logo',
			'settings' => array(
				'header-logo',
			)
		) );
		$wp_customize->selective_refresh->add_partial( 'header-text', array(
			'selector' => '#header-content',
			'settings' => array(
				'header-text',
			)
		) );

		$wp_customize->selective_refresh->add_partial( 'show-footer-widgets', array(
			'selector' => '#site-footer',
			'settings' => array(
				'show-footer-widgets',
			)
		) );
		$wp_customize->selective_refresh->add_partial( 'footer-text', array(
			'selector' => '#footer-content',
			'settings' => array(
				'footer-text',
			)
		) );
		$wp_customize->selective_refresh->add_partial( 'footer-copyright-text', array(
			'selector' => '#footer-copyright',
			'settings' => array(
				'footer-copyright-text',
			)
		) );

		$wp_customize->selective_refresh->add_partial( 'show-single-sidebar', array(
			'selector' => '#right-content',
			'settings' => array(
				'show-single-sidebar',
			)
		) );
		$wp_customize->selective_refresh->add_partial( 'show-related-and-author', array(
			'selector' => '#related_posts',
			'settings' => array(
				'show-related-and-author',
			)
		) );
		$wp_customize->selective_refresh->add_partial( 'show-author-card', array(
			'selector' => '#author_card',
			'settings' => array(
				'show-author-card',
			)
		) );

		$wp_customize->selective_refresh->add_partial( 'first-color', array(
			'selector'			=> 'head > #hayya-style',
			'settings'			=> array(
				'first-color',
				'second-color',
				'third-color',
				'fourth-color',
				'fifth-color',
			),
			'fallback_refresh'	=> false,
			'render_callback'	 => array( 'HayyaThemeCustomize', 'css' ),
		) );

	}

	/**
	 *
	 * sanitize checkbox
	 * @since Hayya 1.0
	 */
	public static function sanitize_checkbox( $input ) {
		return ( isset( $input ) && true === (bool) $input ? true : false );
	}
}
