<?php
/**
 * Login form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( is_user_logged_in() ) {
	return;
}

?>
<form class="woocommerce-form woocommerce-form-login login" method="post" <?php echo ( $hidden ) ? 'style="display:none;"' : ''; ?>>

	<?php do_action( 'woocommerce_login_form_start' ); ?>

	<?php echo ( $message ) ? wpautop( wptexturize( $message ) ) : ''; // @codingStandardsIgnoreLine ?>

	<p class="form-row form-row-first">
		<div class="row">
			<div class="input-field col l5 m5 s12">
				<i class="material-icons prefix">account_circle</i>
				<input type="text" class="validate input-text" name="username" id="username" />
				<label for="username"><?php esc_html_e( 'Username or email', 'hayya' ); ?> <span class="required">*</span></label>
			</div>
			<div class="input-field col l4 m4 s12">
				<i class="material-icons prefix">security</i>
				<input class="validate input-text" type="password" name="password" id="password" />
				<label for="password"><?php esc_html_e( 'Password', 'hayya' ); ?> <span class="required">*</span></label>
			</div>
			<div class="input-field col l3 m3 s12">
				<div class="row no-paddings no-margins">
					<div class="input-field col s12 no-paddings no-margins">
						<button type="submit" class="button waves-effect waves-light" name="login" value="<?php esc_attr_e( 'Login', 'hayya' ); ?>"><?php esc_html_e( 'Login', 'hayya' ); ?></button>
						<input type="hidden" name="redirect" value="<?php echo esc_url( $redirect ) ?>" />
					</div>
					<div class="input-field col s12 no-paddings no-margins">
						<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" />
						<label for="rememberme" class="woocommerce-form__label woocommerce-form__label-for-checkbox inline"><?php esc_html_e( 'Remember me', 'hayya' ); ?></label>
					</div>
				</div>
			</div>
		</div>
	</p>
	<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
	<div class="clear"></div>

	<?php do_action( 'woocommerce_login_form' ); ?>

	<p class="lost_password">
		<a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'hayya' ); ?></a>
	</p>

	<div class="clear"></div>

	<?php do_action( 'woocommerce_login_form_end' ); ?>

</form>
